@@ -18,6 +18,8 @@
 #ifndef LITL_TYPES_H_
 #define LITL_TYPES_H_
 
+#include "litl_config.h"
+
 /**
  * \defgroup litl_types LiTL Data Types and Defined Variables
  */
@@ -50,7 +52,7 @@
 #include <stdio.h>
 #include <stdint.h>
 
-#ifdef USE_GETTID
+#if USE_GETTID
 #include <unistd.h>
 #include <sys/syscall.h>  // For SYS_xxx definitions
 #else
@@ -58,7 +60,7 @@
 #endif
 
 // current thread id
-#ifdef USE_GETTID
+#if USE_GETTID
 /**
  * \ingroup litl_types_general
  * \brief A current thread ID
@@ -72,7 +74,7 @@
 #define CUR_TID pthread_self()
 #endif
 
-#ifdef HAVE_32BIT
+#if HAVE_32BIT
 /**
  * \ingroup litl_types_general
  * \brief A data type for storing thread IDs
@@ -295,6 +297,7 @@ typedef struct {
   litl_offset_t offset; /**< An offset to the next buffer in the trace file */
 
   litl_data_t already_flushed; /**< Handles the situation when some threads start after the header was flushed, i.e. their tids and offsets were not included into the header*/
+  int initialized;
 } litl_write_buffer_t;
 
 /**
@@ -434,7 +437,7 @@ typedef struct {
 #define PRTIu32 "u"
 #define PRTIx32 "x"
 
-#ifdef HAVE_32BIT
+#if HAVE_32BIT
 #define PRTIu64 "u"
 #define PRTIx64 "x"
 
